import type { FileName } from "./FileName";
import type { RelativeOrAbsoluteFolderPath } from "./RelativeOrAbsoluteFolderPath";
/**
 * An object containing a `fileName` and/or `folderPath`.
 *
 * Both fields are optional and support path variables.
 *
 * If a field is omitted, the API key's default value is used for that field. Default values are configured per API key via the Upload Dashboard.
 */
export declare type DynamicFilePath = {
    fileName?: FileName;
    /**
     * If `true` then path variables like `{DATE_UTC}` will be replaced with a generated value. You can escape `{` characters with a `\`.
     *
     * If `false` then path variables like `{DATE_UTC}` will appear literally in the file name.
     *
     * Default: true
     */
    fileNameVariablesEnabled?: boolean;
    folderPath?: RelativeOrAbsoluteFolderPath;
    /**
     * If `true` then path variables like `{DATE_UTC}` will be replaced with a generated value. You can escape `{` characters with a `\`.
     *
     * If `false` then path variables like `{DATE_UTC}` will appear literally in the folder path.
     *
     * Default: true
     */
    folderPathVariablesEnabled?: boolean;
};
