import type { TransformationUrlSlugPattern } from "./TransformationUrlSlugPattern";
/**
 * Permissions relating to the reading of files matched by the outer FolderPublicPermissions object.
 */
export declare type FileReadGrants = {
    /**
     * An array of transformation URL slug patterns.
     *
     * This array specifies which transformation slugs can be used when downloading files from this location.
     *
     * - Use `"*"` to allow all file downloads.
     *
     * - Use `"raw"` to allow raw/original file downloads.
     *
     * - Use a `*` suffix to allow transformation prefixes. For example: `"thumbnail-*"` will allow `thumbnail-sm` and `thumbnail-lg`.
     *
     * - Use any other value to allow specific transformations. For example: `"thumbnail"` will allow `thumbnail` downloads only.
     *
     * - Use an empty array to indicate no file downloads are allowed.
     */
    downloadFile: Array<TransformationUrlSlugPattern>;
    getFileDetails: boolean;
};
